@@ -16,8 +16,15 @@
 Diag <- function(..., binary = FALSE){
     dots <- list(...)
     dots <- lapply(dots, as.factor)
-    Levels <- sort(unique(unlist(lapply(dots, levels))))
-    facMatrix <- sapply(dots, as.character)
+    Levels <- levels(dots[[1]])
+    check <- vapply(dots[-1], function(x) identical(levels(x), Levels), 
+                    TRUE)
+    if (!all(check)){
+        message("Levels are not identical, new factor will be based ",
+                "on sorted combined levels.")
+        Levels <- sort(unique(unlist(lapply(dots, levels))))
+    }
+    facMatrix <- vapply(dots, as.character, character(length(dots[[1]])))
     f <- function(row){
         if (all(is.na(row))) return(NA)
         if (all(!is.na(row)) && all(row == row[1])) return(row[1])
@@ -25,10 +32,7 @@ Diag <- function(..., binary = FALSE){
         if (!all(row == row[1])) return(".")
         return(NA)
     }
-    if (inherits(facMatrix, "matrix"))
-        result <- factor(apply(facMatrix, 1, f), levels = c(".", Levels))
-    else
-        result <- factor(f(facMatrix))
+    result <- factor(apply(facMatrix, 1, f), levels = c(".", Levels))
     if (binary) result <- ifelse(result == ".", 0, 1)
     result
 }
